package com.lantone.qc.kernel.catalogue.operationdiscussion;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.model.doc.operation.OperationInformedConsentDoc;
import com.lantone.qc.pub.util.ListUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.text.ParseException;
import java.util.*;

/**
 * @Description: 使用植入物但手术记录或病程记录未记录相关信息
 * @author: cy
 * @time: 2021/05/19 14:45
 */
@Component
public class OPE03119 extends QCCatalogue {

    @Override
    protected void start(InputInfo inputInfo, OutputInfo outputInfo) throws ParseException {
        status.set("0");
        //先判断有无手术记录
        List<OperationDoc> operationDocs = inputInfo.getOperationDocs();
        long operationCount = 0L;
        if (operationDocs != null && operationDocs.size() > 0) {
             operationCount = operationDocs.stream().map(i -> i.getOperationInformedConsentDoc()).filter(i ->StringUtils.isNotEmpty(i.getStructureMap().get("使用植入性材料")) && StringUtils.isNotEmpty(i.getStructureMap().get("型号和数量符合要求")) && "true".equals(i.getStructureMap().get("使用植入性材料")) && "true".equals(i.getStructureMap().get("型号和数量符合要求"))).count();
        }
        Boolean flag = false;
        Boolean modelFlag = false;
        Boolean numFlag = false;
        List<ThreeLevelWardDoc> threeLevelWardDocList = inputInfo.getThreeLevelWardDocs();
        if (ListUtil.isNotEmpty(threeLevelWardDocList)) {
            List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocList.get(0).getAllDoctorWradDocs();
            for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                String illness = allDoctorWradDoc.getStructureMap().get(Content.illnessRecords);
                //判断病程记录是否记录植入物
                    for (String plant : Content.IMPLANTSLIST) {
                        if (illness.contains(plant)) {
                            flag = true;
                            break;
                        }
                    }

                    for (String model : Content.MODELIST) {
                        if(illness.contains(model)){
                            modelFlag = true;
                            break;
                        }
                    }

                    for (String number : Content.NUMBERLIST) {
                        if(illness.contains(number)){
                            numFlag = true;
                            break;
                        }
                    }
                 }
            }
        if(operationCount <= 0 && flag == false && modelFlag == false  && numFlag == false){
            status.set("-1");
            return;
        }
    }
}