package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.*;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03119
 * @Description: 有抗菌药物使用病程无记录
 * @author: zh
 * @time: 2021/04/06 11:22
 */
@Component
public class THR03119 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 【指标十一】抗菌药物使用记录符合率(MER-D&T-01)
         * 1、判断病案首页中是否存在抗菌药物费用
         * 2、判断医嘱中是否存在抗菌药物的使用
         * 3、若存在抗菌药物费用或者医嘱中存在抗菌药物，查询病程记录，没有记录提示规则
         */
        status.set("0");
        boolean flag = false;
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        List<String> antimicrobialDrugList = Content.antimicrobialDrugList;
        if (firstPageRecordDoc != null) {
            Map<String, String> structureMap = firstPageRecordDoc.getStructureMap();
            String antimicrobialAgents = structureMap.get("抗菌药物费用");
            if (StringUtil.isNotEmpty(antimicrobialAgents) && antimicrobialAgents.equals("0")) {
                double b = Double.parseDouble(antimicrobialAgents);
                if (b > 0) {
                    flag = true;
                }
            }
        }

        if (!flag) {
            //查医嘱
            List<DoctorAdviceDoc> doctorAdviceDocs = inputInfo.getDoctorAdviceDocs();
            for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocs) {
                Map<String, String> structureMap = doctorAdviceDoc.getStructureMap();
                String daStatus = structureMap.get(Content.doctorAdviceState);
                if (StringUtil.isEmpty(daStatus) || (!daStatus.equals(Content.cancellationOrder) && StringUtil.isNotEmpty(daStatus))) {
                    String adviceType = structureMap.get(Content.doctorAdviceType);
                    //取长期和临时医嘱
                    if (adviceType.equals(Content.statOrder) || adviceType.equals(Content.standingOrder)) {
                        String daItemName = structureMap.get(Content.medicalOrderName);
                        for (String antimicrobialDrug : antimicrobialDrugList) {
                            if (daItemName.contains(antimicrobialDrug)) {
                                flag = true;
                            }
                        }
                    }
                }
            }
        }

        if (flag) {
            status.set("-1");
            List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
            if (ListUtil.isNotEmpty(threeLevelWardDocs)) {
                ThreeLevelWardDoc threeLevelWardDoc = threeLevelWardDocs.get(0);
                List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDoc.getAllDoctorWradDocs();
                if (ListUtil.isNotEmpty(allDoctorWradDocs)) {
                    for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                        Map<String, String> wradDocStructureMap = allDoctorWradDoc.getStructureMap();
                        String illnessRecords = wradDocStructureMap.get(Content.illnessRecords);
                        if (StringUtil.isNotEmpty(illnessRecords)) {
                            for (String antimicrobial : antimicrobialDrugList) {
                                if (illnessRecords.contains(antimicrobial)) {
                                    status.set("0");
                                    return;
                                }
                            }
                        }
                    }
                }
            }
        }


    }
}
