package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DoctorAdviceDoc;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR3113
 * @Description :  接受MR情况下病程记录缺少MR检查记录
 * @Author : zh
 * @Date: 2021-04-06 17:06
 */
@Component
public class THR3113 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        int ctNum=0;
        int bcNum=0;
        List<DoctorAdviceDoc> doctorAdviceDocsList = inputInfo.getDoctorAdviceDocs();
        if(ListUtil.isNotEmpty(doctorAdviceDocsList)) {
            for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocsList) {
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
               String daStatus = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                if(StringUtil.isEmpty(daStatus) || (!daStatus.equals(Content.cancellationOrder) && StringUtil.isNotEmpty(daStatus))){
                //ct取临时医嘱
                String doctorAsks = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
                if (StringUtil.isNotEmpty(doctorAsks)) {
                    if (Content.statOrder.equals(doctorAsks)) {
                        //取医嘱项目名称
                        String daItemName = doctorAdviceDocStructureMap.get(Content.medicalOrderName);
                        if (daItemName.contains("磁共振") || daItemName.contains("MR")) {
                            if (!daItemName.contains("IMRT") && !daItemName.contains("mrs评分")) {
                                ctNum++;
                                continue;
                            }
                        }
                    }
                    }
                }
            }
            List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
            if (ListUtil.isNotEmpty(threeLevelWardDocs)) {
                List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
                if (ListUtil.isNotEmpty(allDoctorWradDocs)) {
                    if (allDoctorWradDocs.size() > 0) {
                        for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                            Map<String, String> structureMap = allDoctorWradDoc.getStructureMap();
                            String records = structureMap.get(Content.illnessRecords);
                            if (StringUtil.isNotEmpty(records)) {
                                if (records.contains("MR") || records.contains("磁共振")) {
                                    bcNum++;
                                }
                            }
                        }
                    }
                }
            }
            if((ctNum != bcNum)&&(ctNum>bcNum)){
                status.set("-1");
            }
        }
    }

}
